import {
  Account,
  activeAccountContext,
  createAnonymousJazzContext
} from "./chunk-OJIEP4WE.js";

// src/testing.ts
import { LocalNode } from "cojson";
import { cojsonInternals } from "cojson";
import { PureJSCrypto } from "cojson/crypto";
var syncServer = { current: null };
var TestJSCrypto = class extends PureJSCrypto {
  static async create() {
    if ("navigator" in globalThis && navigator.userAgent.includes("jsdom")) {
      const crypto = new PureJSCrypto();
      crypto.seal = (options) => `sealed_U${cojsonInternals.stableStringify(options.message)}`;
      crypto.unseal = (sealed) => JSON.parse(sealed.substring("sealed_U".length));
      crypto.encrypt = (message) => `encrypted_U${cojsonInternals.stableStringify(message)}`;
      crypto.decryptRaw = (encrypted) => encrypted.substring("encrypted_U".length);
      return crypto;
    }
    return new PureJSCrypto();
  }
};
async function createJazzTestAccount(options) {
  const AccountSchema = options?.AccountSchema ?? Account;
  const peers = [];
  if (syncServer.current) {
    const [aPeer, bPeer] = cojsonInternals.connectedPeers(
      Math.random().toString(),
      Math.random().toString(),
      {
        peer1role: "server",
        peer2role: "server"
      }
    );
    syncServer.current.syncManager.addPeer(aPeer);
    peers.push(bPeer);
  }
  const { node } = await LocalNode.withNewlyCreatedAccount({
    creationProps: {
      name: "Test Account",
      ...options?.creationProps
    },
    crypto: await TestJSCrypto.create(),
    peersToLoadFrom: peers,
    migration: async (rawAccount, _node, creationProps) => {
      const account2 = new AccountSchema({
        fromRaw: rawAccount
      });
      if (options?.isCurrentActiveAccount) {
        activeAccountContext.set(account2);
      }
      await account2.applyMigration?.(creationProps);
    }
  });
  const account = AccountSchema.fromNode(node);
  if (options?.isCurrentActiveAccount) {
    activeAccountContext.set(account);
  }
  return account;
}
function setActiveAccount(account) {
  activeAccountContext.set(account);
}
async function createJazzTestGuest() {
  const ctx = await createAnonymousJazzContext({
    crypto: await PureJSCrypto.create(),
    peersToLoadFrom: []
  });
  return {
    guest: ctx.agent
  };
}
function getJazzContextShape(account) {
  if ("guest" in account) {
    return {
      guest: account.guest,
      AccountSchema: Account,
      logOut: () => account.guest.node.gracefulShutdown(),
      done: () => account.guest.node.gracefulShutdown()
    };
  }
  return {
    me: account,
    AccountSchema: account.constructor,
    logOut: () => account._raw.core.node.gracefulShutdown(),
    done: () => account._raw.core.node.gracefulShutdown()
  };
}
function linkAccounts(a, b, aRole = "server", bRole = "server") {
  const [aPeer, bPeer] = cojsonInternals.connectedPeers(b.id, a.id, {
    peer1role: aRole,
    peer2role: bRole
  });
  a._raw.core.node.syncManager.addPeer(aPeer);
  b._raw.core.node.syncManager.addPeer(bPeer);
}
async function setupJazzTestSync() {
  if (syncServer.current) {
    syncServer.current.gracefulShutdown();
  }
  const account = await Account.create({
    creationProps: {
      name: "Test Account"
    },
    crypto: await TestJSCrypto.create()
  });
  syncServer.current = account._raw.core.node;
  return account;
}
export {
  createJazzTestAccount,
  createJazzTestGuest,
  getJazzContextShape,
  linkAccounts,
  setActiveAccount,
  setupJazzTestSync
};
//# sourceMappingURL=testing.js.map